Index: src/heap/heap.h |
diff --git a/src/heap/heap.h b/src/heap/heap.h |
index 750827968dcd757edff47ece2ed0948930aa688f..45ff17e4b2e366e6c45e6388d64a6d8058044d85 100644 |
--- a/src/heap/heap.h |
+++ b/src/heap/heap.h |
@@ -952,9 +952,9 @@ class Heap { |
void IterateWeakRoots(ObjectVisitor* v, VisitMode mode); |
// Iterate pointers to from semispace of new space found in memory interval |
- // from start to end. |
- void IterateAndMarkPointersToFromSpace(bool record_slots, Address start, |
- Address end, |
+ // from start to end within |object|. |
+ void IterateAndMarkPointersToFromSpace(HeapObject* object, Address start, |
+ Address end, bool record_slots, |
ObjectSlotCallback callback); |
// Returns whether the object resides in new space. |